@@ -53,10 +53,14 @@ nepim_global_t nepim_global = {
   500000,  /* udp_keepalive_delay (usec, non-senders) */
   1,       /* udp_keepalive_require (boolean, receivers) */
   1,       /* udp_keepalive_send (boolean, non-senders) */
-  1000,    /* udp_win_max */
+  4000,    /* udp_win_max */
   -1,      /* win_recv */
   -1,      /* win_send */
   1,       /* udp_require_greet_reply (boolean, client) */
+  0,       /* password */
+  0,       /* udp_exp_stats */
+  0,       /* udp_exp_loss */
+  0,       /* udp_exp_dup */
 
   0, /* oop source */
   0  /* source interface */
