@@ -64,6 +64,10 @@ struct nepim_global_t {
   int         win_recv;
   int         win_send;
   int         udp_require_greet_reply; /* boolean, client */
+  const char *password;
+  int         udp_exp_stats;           /* boolean */
+  int         udp_exp_loss;
+  int         udp_exp_dup;
 
   oop_source_sys *oop_sys;
   oop_source     *oop_src;
