@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: greet.c,v 1.6 2005/09/09 22:40:37 evertonm Exp $ */
+/* $Id: greet.c,v 1.7 2005/09/20 23:04:22 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -28,6 +28,7 @@ Boston, MA 02111-1307, USA.
 
 #include "conf.h"
 #include "greet.h"
+#include "common.h"
 
 const char *GREET_SERVER_SEND       = "server_send=";
 const char *GREET_BIT_RATE          = "bit_rate=";
@@ -37,6 +38,7 @@ const char *GREET_TEST_DURATION     = "test_duration=";
 const char *GREET_WRITE_DELAY       = "write_delay=";
 const char *GREET_SERVER_KA_SEND    = "server_ka_send=";
 const char *GREET_SERVER_KA_REQUIRE = "server_ka_req=";
+const char *GREET_PASSWORD          = "password=";
 
 #define NEPIM_GREET_PARSE_OK     (0)
 #define NEPIM_GREET_PARSE_FTOKEN (-1)
@@ -50,10 +52,16 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
 {
   int pr;
 
+  assert(opt->password_buf);
+  assert(opt->password_buf_size > 0);
+  assert(memchr(opt->password_buf, '\0', opt->password_buf_size));
+  assert(strlen(opt->password_buf) >= 0);
+  assert(strlen(opt->password_buf) < opt->password_buf_size);
+
   pr = snprintf(buf, buf_size,
 		"hello %s%d %s%lld "
 		"%s%d %s%d %s%d "
-		"%s%ld %s%d %s%d\n", 
+		"%s%ld %s%d %s%d %s%s\n", 
 		GREET_SERVER_SEND,       opt->must_send,
 		GREET_BIT_RATE,          opt->bit_rate,
 		GREET_PKT_RATE,          opt->pkt_rate,
@@ -61,7 +69,8 @@ int nepim_write_greetings(const nepim_greet_t *opt, char *buf, int buf_size)
 		GREET_TEST_DURATION,     opt->test_duration,
 		GREET_WRITE_DELAY,       opt->write_delay,
 		GREET_SERVER_KA_SEND,    opt->udp_keepalive_send,
-		GREET_SERVER_KA_REQUIRE, opt->udp_keepalive_require);
+		GREET_SERVER_KA_REQUIRE, opt->udp_keepalive_require,
+		GREET_PASSWORD,          opt->password_buf);
 
   if (pr < 1)
     return NEPIM_GREET_WRITE_IO;
@@ -82,6 +91,10 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   const char *tok;
   char *ptr;
 
+  assert(opt->password_buf);
+  assert(opt->password_buf_size > 0);
+  *opt->password_buf = '\0';
+
   const int GREET_SERVER_SEND_LEN       = strlen(GREET_SERVER_SEND);
   const int GREET_BIT_RATE_LEN          = strlen(GREET_BIT_RATE);
   const int GREET_PKT_RATE_LEN          = strlen(GREET_PKT_RATE);
@@ -90,6 +103,7 @@ int nepim_parse_greetings(nepim_greet_t *opt,
   const int GREET_WRITE_DELAY_LEN       = strlen(GREET_WRITE_DELAY);
   const int GREET_SERVER_KA_SEND_LEN    = strlen(GREET_SERVER_KA_SEND);
   const int GREET_SERVER_KA_REQUIRE_LEN = strlen(GREET_SERVER_KA_REQUIRE);
+  const int GREET_PASSWORD_LEN          = strlen(GREET_PASSWORD);
 
   int server_send       = -2;
   long long bit_rate    = -2;
@@ -155,10 +169,45 @@ int nepim_parse_greetings(nepim_greet_t *opt,
       continue;
     }
 
+    if (!strncmp(tok, GREET_PASSWORD, GREET_PASSWORD_LEN)) {
+      const char *tmp_past_end = tmp + sizeof(tmp);
+      const char *pass;
+      const char *end;
+      int pass_len;
+      int rem;
+
+      pass = tok + GREET_PASSWORD_LEN;
+      rem = tmp_past_end - pass;
+      end = memchr(pass, ' ', rem);
+      if (!end)
+	end = memchr(pass, '\0', rem);
+      if (!end)
+	end = tmp_past_end;
+      
+      pass_len = NEPIM_MIN(opt->password_buf_size - 1, end - pass);
+
+      assert(pass_len >= 0);
+      assert(pass_len < opt->password_buf_size);
+
+      memcpy(opt->password_buf, pass, pass_len);
+      opt->password_buf[pass_len] = '\0';
+
+      assert(memchr(opt->password_buf, '\0', opt->password_buf_size));
+      assert(strlen(opt->password_buf) >= 0);
+      assert(strlen(opt->password_buf) < opt->password_buf_size);
+      assert(strlen(opt->password_buf) == pass_len);
+
+      continue;
+    }
+
     fprintf(stderr, "%s %s: unknown greeting parameter: '%s'\n",
 	    __FILE__, __PRETTY_FUNCTION__, tok);
   }
 
+  assert(memchr(opt->password_buf, '\0', opt->password_buf_size));
+  assert(strlen(opt->password_buf) >= 0);
+  assert(strlen(opt->password_buf) < opt->password_buf_size);
+
   if (write_delay < 0)
     write_delay = nepim_global.write_delay;
 
