@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: greet.h,v 1.5 2005/08/16 21:57:16 evertonm Exp $ */
+/* $Id: greet.h,v 1.6 2005/09/20 23:04:22 evertonm Exp $ */
 
 #ifndef NEPIM_GREET_H
 #define NEPIM_GREET_H
@@ -35,6 +35,8 @@ struct nepim_greet_t {
   long      write_delay;
   int       udp_keepalive_send;
   int       udp_keepalive_require;
+  char      *password_buf;
+  int       password_buf_size;
 };
 
 int nepim_write_greetings(const nepim_greet_t *opt, char *buf,
