@@ -21,7 +21,7 @@ Boston, MA 02111-1307, USA.
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.25 2005/09/18 19:37:00 evertonm Exp $
+  $Id: main.c,v 1.29 2005/09/29 12:48:38 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -93,8 +93,12 @@ static void usage(FILE *out, const char *prog_name)
 	  "  -Z size       UDP read size (defaults to %d bytes)\n"
 	  "  -O size       maximum socket send buffer in bytes\n"
 	  "  -I size       maximum socket receive buffer in bytes\n"
+	  "  -k password   server authentication secret\n"
 	  "  -6            disable IPv6\n"
 	  "  -4            disable IPv4\n"
+	  "  -x [win]      experimental UDP reception statistics (win=%d)\n"
+	  "  -L loss       experimental UDP sending loss\n"
+	  "  -D dup        experimental UDP sending duplication\n"
 	  "client-only options:\n"
 	  "  -u            UDP mode (defaults to TCP)\n"
 	  "  -s            client-send simplex mode (defaults to server-send)\n"
@@ -121,6 +125,7 @@ static void usage(FILE *out, const char *prog_name)
 	  nepim_global.tcp_read_size,
 	  nepim_global.udp_write_size,
 	  nepim_global.udp_read_size,
+	  nepim_global.udp_win_max,
 	  nepim_global.pipes,
 	  bit_rate,
 	  pkt_rate,
@@ -176,6 +181,41 @@ int main(int argc, const char *argv[])
   for (i = 1; i < argc; ++i) {
     const char *arg = argv[i];
 
+    if (!strcmp(arg, "-L")) {
+      ++i;
+      if (i >= argc) {
+	fprintf(stderr, "%s: missing UDP loss\n",
+		nepim_global.prog_name);
+	exit(1);
+      }
+      nepim_global.udp_exp_loss = atoi(argv[i]);
+      continue;
+    }
+
+    if (!strcmp(arg, "-D")) {
+      ++i;
+      if (i >= argc) {
+	fprintf(stderr, "%s: missing UDP duplication\n",
+		nepim_global.prog_name);
+	exit(1);
+      }
+      nepim_global.udp_exp_dup = atoi(argv[i]);
+      continue;
+    }
+
+    if (!strcmp(arg, "-x")) {
+      int j = i + 1;
+      nepim_global.udp_exp_stats = 1;
+
+      if (j < argc)
+	if (*argv[j] != '-') {
+	  ++i;
+	  nepim_global.udp_win_max = atoi(argv[i]);
+	}
+
+      continue;
+    }
+
     if (!strcmp(arg, "-4")) {
       nepim_global.no_inet4 = 1;
       continue;
@@ -186,6 +226,17 @@ int main(int argc, const char *argv[])
       continue;
     }
 
+    if (!strcmp(arg, "-k")) {
+      ++i;
+      if (i >= argc) {
+	fprintf(stderr, "%s: missing password\n",
+		nepim_global.prog_name);
+	exit(1);
+      }
+      nepim_global.password = argv[i];
+      continue;
+    }
+
     if (!strcmp(arg, "-a")) {
       ++i;
       if (i >= argc) {
