@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: pipe.c,v 1.5 2005/07/29 23:08:58 evertonm Exp $ */
+/* $Id: pipe.c,v 1.6 2005/08/15 17:41:17 evertonm Exp $ */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -38,13 +38,17 @@ nepim_pipe_t *nepim_pipe_set_get(const nepim_pipe_set_t *set, int sd)
 }
 
 void nepim_pipe_set_add(nepim_pipe_set_t *set, int sd, 
+			const struct sockaddr *remote,
+			socklen_t remote_len,
 			const nepim_greet_t *opt)
 {
   nepim_pipe_t *pipe = malloc(sizeof(*pipe));
   assert(pipe);
 
   pipe->sd = sd;
-  nepim_session_init(&pipe->session, opt, SESSION_PIPE, sd);
+  nepim_session_init(&pipe->session, opt, 
+		     remote, remote_len,
+		     SESSION_PIPE, sd);
 
   nepim_array_add(&set->array, sd, pipe);
 }
