@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: server.c,v 1.39 2005/09/18 19:37:00 evertonm Exp $ */
+/* $Id: server.c,v 1.42 2005/09/22 10:24:56 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -63,15 +63,22 @@ static void *on_tcp_read(oop_source *src, int sd,
 
   assert(nepim_global.tcp_read_size = sizeof(buf));
 
+  errno = 0;
+
   rd = read(sd, buf, nepim_global.tcp_read_size);
-  if (rd < 0) {
-    switch (errno) {
-    case EINTR:
-      fprintf(stderr, "read: EINTR on TCP socket %d\n", sd);
-      return OOP_CONTINUE;
-    case EAGAIN:
-      fprintf(stderr, "read: EAGAIN on TCP socket %d\n", sd);
-      return OOP_CONTINUE;
+  if (rd <= 0) {
+    if (rd) {
+      switch (errno) {
+      case EINTR:
+	fprintf(stderr, "read: EINTR on TCP socket %d\n", sd);
+	return OOP_CONTINUE;
+      case EAGAIN:
+	fprintf(stderr, "read: EAGAIN on TCP socket %d\n", sd);
+	return OOP_CONTINUE;
+      default:
+	fprintf(stderr, "read: errno=%d: %s\n",
+		errno, strerror(errno));
+      }
     }
 
     fprintf(stderr, "read: connection lost on TCP socket %d\n", sd);
@@ -340,18 +347,31 @@ static int parse_greetings(int sd,
 {
   nepim_greet_t opt;
   int result;
+  char password_buf[100];
+
+  opt.password_buf = password_buf;
+  opt.password_buf_size = sizeof(password_buf);
 
   result = nepim_parse_greetings(&opt, buf, past_end);
   if (result)
     return result;
 
   fprintf(stderr, 
-	  "%d: TCP incoming: send=%d bit_rate=%lld pkt_rate=%d "
-	  "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d\n", 
+	  "%d: send=%d bit_rate=%lld pkt_rate=%d "
+	  "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d "
+	  "password=%s\n", 
 	  sd, opt.must_send, opt.bit_rate, opt.pkt_rate,
 	  opt.stat_interval, opt.test_duration, 
 	  opt.write_delay, opt.udp_keepalive_send,
-	  opt.udp_keepalive_require);
+	  opt.udp_keepalive_require,
+	  password_buf);
+
+  if (nepim_global.password)
+    if (strcmp(nepim_global.password, password_buf)) {
+      fprintf(stderr, "%d: bad client password=%s\n",
+	      sd, password_buf);
+      return 1;
+    }
 
   nepim_pipe_set_add(&pipes, sd, remote, remote_len, &opt);
 
@@ -542,21 +562,30 @@ static void *on_tcp_connect(oop_source *src, int sd,
   } sa;
   int len = sizeof(sa);
   int result;
+  char addr_buf[100];
 
   conn_sd = accept(sd, (struct sockaddr *) &sa, &len);
   if (conn_sd < 0) {
     fprintf(stderr, 
-	    "%s: could not accept connection: %s\n", 
-	    __PRETTY_FUNCTION__, strerror(errno));
+	    "%s: %s: could not accept connection: errno=%d: %s\n", 
+	    __FILE__, __PRETTY_FUNCTION__, errno, strerror(errno));
     return OOP_CONTINUE;
   }
 
+  nepim_sock_dump_addr(addr_buf, sizeof(addr_buf),
+		       (const struct sockaddr *) &sa);
+
+  fprintf(stderr,
+	  "%d: TCP incoming: %s,%d\n",
+	  conn_sd, addr_buf, 
+	  nepim_sock_get_port((const struct sockaddr *) &sa));
+
   result = nepim_socket_opt(conn_sd, nepim_global.pmtu_mode, 
 			    nepim_global.ttl);
   if (result) {
     fprintf(stderr, 
-	    "%s: could not set socket options: %d\n",
-	    __PRETTY_FUNCTION__, result);
+	    "%d: %s: %s: could not set socket options: %d\n",
+	    conn_sd, __FILE__, __PRETTY_FUNCTION__, result);
     close(conn_sd);
     return OOP_CONTINUE;
   }
@@ -564,32 +593,32 @@ static void *on_tcp_connect(oop_source *src, int sd,
   result = nepim_socket_tcp_opt(conn_sd);
   if (result) {
     fprintf(stderr, 
-	    "%s: could not set tcp options: %d\n",
-	    __PRETTY_FUNCTION__, result);
+	    "%d: %s: %s: could not set tcp options: %d\n",
+	    conn_sd, __FILE__, __PRETTY_FUNCTION__, result);
     close(conn_sd);
     return OOP_CONTINUE;
   }
 
   if (nepim_socket_block(conn_sd)) {
     fprintf(stderr, 
-	    "%s: could not set blocking socket mode\n",
-	    __PRETTY_FUNCTION__);
+	    "%d: %s: %s: could not set blocking socket mode\n",
+	    conn_sd, __FILE__, __PRETTY_FUNCTION__);
     close(conn_sd);
     return OOP_CONTINUE;
   }
 
   if (read_greetings(conn_sd, (const struct sockaddr *) &sa, len)) {
     fprintf(stderr, 
-	    "%s: could not parse client greetings\n",
-	    __PRETTY_FUNCTION__);
+	    "%d: %s: %s: could not parse client greetings\n",
+	    conn_sd, __FILE__, __PRETTY_FUNCTION__);
     close(conn_sd);
     return OOP_CONTINUE;
   }
 
   if (nepim_socket_nonblock(conn_sd)) {
     fprintf(stderr, 
-	    "%s: could not set non-blocking socket mode\n",
-	    __PRETTY_FUNCTION__);
+	    "%d: %s: %s: could not set non-blocking socket mode\n",
+	    conn_sd, __FILE__, __PRETTY_FUNCTION__);
     close(conn_sd);
     return OOP_CONTINUE;
   }
