@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: sock.c,v 1.24 2005/09/18 19:37:00 evertonm Exp $ */
+/* $Id: sock.c,v 1.25 2005/09/20 19:59:50 evertonm Exp $ */
 
 
 #include <assert.h>
@@ -351,6 +351,16 @@ int nepim_create_socket(struct sockaddr *addr,
     assert(protocol == IPPROTO_UDP);
     
     if (socket_mcast_join(sd, family, addr, addr_len)) {
+      char buf[INET6_ADDRSTRLEN];
+      int e = errno;
+
+      nepim_sock_dump_addr(buf, sizeof(buf), addr);
+
+      fprintf(stderr, "%s: %s: mcast_join(%d,%s,%d): errno=%d: %s\n",
+	      __FILE__, __PRETTY_FUNCTION__,
+	      sd, buf, nepim_sock_get_port(addr),
+	      e, strerror(e));
+
       close(sd);
       return NEPIM_SOCK_ERR_MCAST_JOIN;
     }
@@ -363,6 +373,16 @@ int nepim_create_socket(struct sockaddr *addr,
   }
 
   if (bind(sd, addr, addr_len)) {
+    char buf[INET6_ADDRSTRLEN];
+    int e = errno;
+
+    nepim_sock_dump_addr(buf, sizeof(buf), addr);
+
+    fprintf(stderr, "%s: %s: bind(%d,%s,%d): errno=%d: %s\n",
+	    __FILE__, __PRETTY_FUNCTION__,
+	    sd, buf, nepim_sock_get_port(addr),
+	    e, strerror(e));
+
     close(sd);
     return NEPIM_SOCK_ERR_BIND;
   }
@@ -491,9 +511,9 @@ int nepim_connect_client_socket(struct sockaddr *addr,
 
     nepim_sock_dump_addr(buf, sizeof(buf), addr);
 
-    fprintf(stderr, "%s: %s: connect(%s,%d): errno=%d: %s\n",
+    fprintf(stderr, "%s: %s: connect(%d,%s,%d): errno=%d: %s\n",
 	    __FILE__, __PRETTY_FUNCTION__,
-	    buf, nepim_sock_get_port(addr),
+	    sd, buf, nepim_sock_get_port(addr),
 	    e, strerror(e));
 
     close(sd);
