@@ -44,7 +44,9 @@ int nepim_create_socket(struct sockaddr *addr,
 			int protocol,
 			int pmtu_mode,
 			int ttl,
-			int mcast_join);
+			int mcast_join,
+			int win_recv,
+			int win_send);
 int nepim_create_listener_socket(struct sockaddr *addr,
 				 int addr_len,
 				 int family,
@@ -52,16 +54,22 @@ int nepim_create_listener_socket(struct sockaddr *addr,
 				 int protocol,
 				 int backlog,
 				 int pmtu_mode,
-				 int ttl);
+				 int ttl,
+				 int win_recv,
+				 int win_send);
 int nepim_connect_client_socket(struct sockaddr *addr,
 				int addr_len,
 				int family,
 				int type,
 				int protocol,
 				int pmtu_mode,
-				int ttl);
+				int ttl,
+				int win_recv,
+				int win_send);
 
 int nepim_sock_get_port(const struct sockaddr *addr);
+void nepim_sock_dump_addr(char *buf, int size, const struct sockaddr *addr);
+int nepim_sock_family(const struct sockaddr *addr);
 void nepim_sock_show_opt(FILE *out, int sd);
 
 #endif /* NEPIM_SOCK_H */
