@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: udp_server.c,v 1.62 2005/09/18 19:37:00 evertonm Exp $ */
+/* $Id: udp_server.c,v 1.65 2005/09/23 12:55:13 evertonm Exp $ */
 
 
 #include <stdio.h>
@@ -659,6 +659,7 @@ static int parse_greetings(nepim_greet_t *opt,
   char *eos;
   char *past_end;
   char peer[100];
+  char password_buf[100];
 
   eos = memchr(buf, '\n', buf_len);
   if (eos)
@@ -671,6 +672,9 @@ static int parse_greetings(nepim_greet_t *opt,
 
   *past_end = '\0';
 
+  opt->password_buf = password_buf;
+  opt->password_buf_size = sizeof(password_buf);
+
   result = nepim_parse_greetings(opt, buf, past_end);
   if (result)
     return result;
@@ -680,7 +684,8 @@ static int parse_greetings(nepim_greet_t *opt,
 
   fprintf(stderr, 
 	  "%d %d-%d: UDP from (%s,%d): send=%d bps=%lld pps=%d "
-	  "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d\n", 
+	  "interval=%d duration=%d delay=%ld ka_send=%d ka_req=%d "
+	  "password=%s\n", 
 	  sd, 
 	  local_slot, remote_slot,
 	  peer,
@@ -688,7 +693,14 @@ static int parse_greetings(nepim_greet_t *opt,
 	  opt->must_send, opt->bit_rate, opt->pkt_rate,
 	  opt->stat_interval, opt->test_duration, 
 	  opt->write_delay, opt->udp_keepalive_send,
-	  opt->udp_keepalive_require);
+	  opt->udp_keepalive_require, password_buf);
+
+  if (nepim_global.password)
+    if (strcmp(nepim_global.password, password_buf)) {
+      fprintf(stderr, "%d: bad client password=%s\n",
+	      sd, password_buf);
+      return 1;
+    }
 
   return 0;
 }
@@ -702,8 +714,9 @@ static void udp_consume(nepim_slot_t *slot, size_t len, uint32_t seq)
 
   nepim_session_read_add(session, len);
 
-  nepim_win_add(&slot->win_recv_seq, seq,
-		&slot->interval_pkt_lost, &slot->interval_pkt_dup);
+  if (nepim_global.udp_exp_stats)
+    nepim_win_add(&slot->win_recv_seq, seq,
+		  &slot->interval_pkt_lost, &slot->interval_pkt_dup);
 }
 
 static void *on_udp_segment(oop_source *src, int sd,
