@@ -18,7 +18,7 @@ the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
-/* $Id: win.h,v 1.1 2005/08/18 21:59:11 evertonm Exp $ */
+/* $Id: win.h,v 1.5 2005/09/30 11:55:40 evertonm Exp $ */
 
 #ifndef NEPIM_WIN_H
 #define NEPIM_WIN_H
@@ -30,14 +30,15 @@ typedef struct nepim_win_t nepim_win_t;
 
 struct nepim_win_t {
   nepim_bit_t bit_set;
-  uint32_t    seq_begin;
   uint32_t    seq_expect;
+  uint32_t    highest_seen_seq;
   int         max_size;
 };
 
 void nepim_win_init(nepim_win_t *win, uint32_t max_size);
 void nepim_win_del(nepim_win_t *win);
 
-int nepim_win_add(nepim_win_t *win, uint32_t seq, int *lost, int *dup);
+void nepim_win_add(nepim_win_t *win, uint32_t seq, int *lost, int *dup);
+int nepim_win_extract_loss(nepim_win_t *win);
 
 #endif /* NEPIM_WIN_H */
